#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.shapes import _DrawingEditorMixin, Drawing, Group, Rect, Line, String, PolyLine, Polygon
from reportlab.lib.colors import Color, CMYKColor, PCMYKColor

class ExplodedDrawing_Drawing(_DrawingEditorMixin,Drawing):
	def __init__(self,width=400,height=200,*args,**kw):
		Drawing.__init__(self,width,height,*args,**kw)
		self.transform = (1,0,0,1,0,0)
		self.add(Rect(50,50,300,125,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,50,350,50,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,50,50,45,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(110,50,110,45,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(170,50,170,45,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(230,50,230,45,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(290,50,290,45,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(350,50,350,45,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,50,45)
		v0.add(String(-2.5,-10,'0',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,110,45)
		v0.add(String(-2.5,-10,'1',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,170,45)
		v0.add(String(-2.5,-10,'2',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,230,45)
		v0.add(String(-2.5,-10,'3',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,290,45)
		v0.add(String(-2.5,-10,'4',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,350,45)
		v0.add(String(-2.5,-10,'5',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		self.add(Line(50,50,50,175,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,50,45,50,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,67.85714,45,67.85714,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,85.71429,45,85.71429,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,103.5714,45,103.5714,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,121.4286,45,121.4286,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,139.2857,45,139.2857,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,157.1429,45,157.1429,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,175,45,175,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,50)
		v0.add(String(-5,-4,'0',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,67.85714)
		v0.add(String(-5,-4,'1',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,85.71429)
		v0.add(String(-5,-4,'2',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,103.5714)
		v0.add(String(-5,-4,'3',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,121.4286)
		v0.add(String(-5,-4,'4',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,139.2857)
		v0.add(String(-5,-4,'5',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,157.1429)
		v0.add(String(-5,-4,'6',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,175)
		v0.add(String(-5,-4,'7',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		self.add(PolyLine(points=[110,67.85714,170,85.71429,200,67.85714,230,103.5714,290,139.2857],strokeColor=Color(1,0,0,1),strokeWidth=2,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(PolyLine(points=[110,85.71429,170,103.5714,200,85.71429,260,139.2857,290,157.1429],strokeColor=Color(0,0,1,1),strokeWidth=4,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (.1,0,0,.1,110,67.85714)
		v0.add(Rect(-0.05,-0.05,20.15,10.1,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=None,strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,0,200,100,rx=0,ry=0,fillColor=Color(0,0,.501961,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,0,22.5,0,200,88.75,200,100,177.5,100,0,11.25],fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,88.75,0,100,22.5,100,200,11.25,200,0,177.5,0],fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,93.33333,60,65,70,65,0,100],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,0,70,35,80,35,10,0],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[200,100,130,65,120,65,190,100],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[200,6.666667,140,35,130,35,200,0],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(84,0,32,100,rx=0,ry=0,fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,35,200,30,rx=0,ry=0,fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(90,0,20,100,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,40,200,20,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (.1,0,0,.1,170,85.71429)
		v0.add(Rect(-0.05,-0.05,20.15,10.1,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=None,strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,0,200,100,rx=0,ry=0,fillColor=Color(0,0,.501961,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,0,22.5,0,200,88.75,200,100,177.5,100,0,11.25],fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,88.75,0,100,22.5,100,200,11.25,200,0,177.5,0],fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,93.33333,60,65,70,65,0,100],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,0,70,35,80,35,10,0],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[200,100,130,65,120,65,190,100],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[200,6.666667,140,35,130,35,200,0],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(84,0,32,100,rx=0,ry=0,fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,35,200,30,rx=0,ry=0,fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(90,0,20,100,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,40,200,20,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (.1,0,0,.1,200,67.85714)
		v0.add(Rect(-0.05,-0.05,20.15,10.1,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=None,strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,0,200,100,rx=0,ry=0,fillColor=Color(0,0,.501961,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,0,22.5,0,200,88.75,200,100,177.5,100,0,11.25],fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,88.75,0,100,22.5,100,200,11.25,200,0,177.5,0],fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,93.33333,60,65,70,65,0,100],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,0,70,35,80,35,10,0],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[200,100,130,65,120,65,190,100],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[200,6.666667,140,35,130,35,200,0],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(84,0,32,100,rx=0,ry=0,fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,35,200,30,rx=0,ry=0,fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(90,0,20,100,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,40,200,20,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (.1,0,0,.1,230,103.5714)
		v0.add(Rect(-0.05,-0.05,20.15,10.1,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=None,strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,0,200,100,rx=0,ry=0,fillColor=Color(0,0,.501961,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,0,22.5,0,200,88.75,200,100,177.5,100,0,11.25],fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,88.75,0,100,22.5,100,200,11.25,200,0,177.5,0],fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,93.33333,60,65,70,65,0,100],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,0,70,35,80,35,10,0],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[200,100,130,65,120,65,190,100],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[200,6.666667,140,35,130,35,200,0],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(84,0,32,100,rx=0,ry=0,fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,35,200,30,rx=0,ry=0,fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(90,0,20,100,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,40,200,20,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (.1,0,0,.1,290,139.2857)
		v0.add(Rect(-0.05,-0.05,20.15,10.1,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=None,strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,0,200,100,rx=0,ry=0,fillColor=Color(0,0,.501961,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,0,22.5,0,200,88.75,200,100,177.5,100,0,11.25],fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,88.75,0,100,22.5,100,200,11.25,200,0,177.5,0],fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,93.33333,60,65,70,65,0,100],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,0,70,35,80,35,10,0],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[200,100,130,65,120,65,190,100],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[200,6.666667,140,35,130,35,200,0],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(84,0,32,100,rx=0,ry=0,fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,35,200,30,rx=0,ry=0,fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(90,0,20,100,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,40,200,20,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (.1,0,0,.1,110,85.71429)
		v0.add(Rect(-0.05,-0.05,20.15,10.1,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=None,strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,0,200,100,rx=0,ry=0,fillColor=Color(0,0,.501961,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,0,22.5,0,200,88.75,200,100,177.5,100,0,11.25],fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,88.75,0,100,22.5,100,200,11.25,200,0,177.5,0],fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,93.33333,60,65,70,65,0,100],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,0,70,35,80,35,10,0],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[200,100,130,65,120,65,190,100],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[200,6.666667,140,35,130,35,200,0],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(84,0,32,100,rx=0,ry=0,fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,35,200,30,rx=0,ry=0,fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(90,0,20,100,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,40,200,20,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (.1,0,0,.1,170,103.5714)
		v0.add(Rect(-0.05,-0.05,20.15,10.1,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=None,strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,0,200,100,rx=0,ry=0,fillColor=Color(0,0,.501961,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,0,22.5,0,200,88.75,200,100,177.5,100,0,11.25],fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,88.75,0,100,22.5,100,200,11.25,200,0,177.5,0],fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,93.33333,60,65,70,65,0,100],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,0,70,35,80,35,10,0],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[200,100,130,65,120,65,190,100],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[200,6.666667,140,35,130,35,200,0],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(84,0,32,100,rx=0,ry=0,fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,35,200,30,rx=0,ry=0,fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(90,0,20,100,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,40,200,20,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (.1,0,0,.1,200,85.71429)
		v0.add(Rect(-0.05,-0.05,20.15,10.1,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=None,strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,0,200,100,rx=0,ry=0,fillColor=Color(0,0,.501961,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,0,22.5,0,200,88.75,200,100,177.5,100,0,11.25],fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,88.75,0,100,22.5,100,200,11.25,200,0,177.5,0],fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,93.33333,60,65,70,65,0,100],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,0,70,35,80,35,10,0],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[200,100,130,65,120,65,190,100],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[200,6.666667,140,35,130,35,200,0],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(84,0,32,100,rx=0,ry=0,fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,35,200,30,rx=0,ry=0,fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(90,0,20,100,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,40,200,20,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (.1,0,0,.1,260,139.2857)
		v0.add(Rect(-0.05,-0.05,20.15,10.1,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=None,strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,0,200,100,rx=0,ry=0,fillColor=Color(0,0,.501961,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,0,22.5,0,200,88.75,200,100,177.5,100,0,11.25],fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,88.75,0,100,22.5,100,200,11.25,200,0,177.5,0],fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,93.33333,60,65,70,65,0,100],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,0,70,35,80,35,10,0],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[200,100,130,65,120,65,190,100],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[200,6.666667,140,35,130,35,200,0],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(84,0,32,100,rx=0,ry=0,fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,35,200,30,rx=0,ry=0,fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(90,0,20,100,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,40,200,20,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (.1,0,0,.1,290,157.1429)
		v0.add(Rect(-0.05,-0.05,20.15,10.1,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=None,strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,0,200,100,rx=0,ry=0,fillColor=Color(0,0,.501961,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,0,22.5,0,200,88.75,200,100,177.5,100,0,11.25],fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,88.75,0,100,22.5,100,200,11.25,200,0,177.5,0],fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,93.33333,60,65,70,65,0,100],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[0,0,70,35,80,35,10,0],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[200,100,130,65,120,65,190,100],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[200,6.666667,140,35,130,35,200,0],fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(84,0,32,100,rx=0,ry=0,fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,35,200,30,rx=0,ry=0,fillColor=Color(.960784,1,.980392,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(90,0,20,100,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,40,200,20,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))


if __name__=="__main__": #NORUNTESTS
	ExplodedDrawing_Drawing().save(formats=['pdf'],outDir='.',fnRoot=None)



#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.shapes import _DrawingEditorMixin, Drawing, Group, Rect, Line, String
from reportlab.lib.colors import Color, CMYKColor, PCMYKColor

class ExplodedDrawing_Drawing(_DrawingEditorMixin,Drawing):
	def __init__(self,width=400,height=200,*args,**kw):
		Drawing.__init__(self,width,height,*args,**kw)
		self.transform = (1,0,0,1,0,0)
		self.add(Rect(50,50,300,125,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(67.57812,50,23.4375,1.041667,rx=0,ry=0,fillColor=Color(0,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(67.57812,51.04167,23.4375,1.041667,rx=0,ry=0,fillColor=Color(0,0,.052632,1),fillOpacity=None,strokeColor=Color(0,0,.052632,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(67.57812,52.08333,23.4375,1.041667,rx=0,ry=0,fillColor=Color(0,0,.105263,1),fillOpacity=None,strokeColor=Color(0,0,.105263,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(67.57812,53.125,23.4375,1.041667,rx=0,ry=0,fillColor=Color(0,0,.157895,1),fillOpacity=None,strokeColor=Color(0,0,.157895,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(67.57812,54.16667,23.4375,1.041667,rx=0,ry=0,fillColor=Color(0,0,.210526,1),fillOpacity=None,strokeColor=Color(0,0,.210526,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(67.57812,55.20833,23.4375,1.041667,rx=0,ry=0,fillColor=Color(0,0,.263158,1),fillOpacity=None,strokeColor=Color(0,0,.263158,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(67.57812,56.25,23.4375,1.041667,rx=0,ry=0,fillColor=Color(0,0,.315789,1),fillOpacity=None,strokeColor=Color(0,0,.315789,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(67.57812,57.29167,23.4375,1.041667,rx=0,ry=0,fillColor=Color(0,0,.368421,1),fillOpacity=None,strokeColor=Color(0,0,.368421,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(67.57812,58.33333,23.4375,1.041667,rx=0,ry=0,fillColor=Color(0,0,.421053,1),fillOpacity=None,strokeColor=Color(0,0,.421053,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(67.57812,59.375,23.4375,1.041667,rx=0,ry=0,fillColor=Color(0,0,.473684,1),fillOpacity=None,strokeColor=Color(0,0,.473684,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(67.57812,60.41667,23.4375,1.041667,rx=0,ry=0,fillColor=Color(0,0,.526316,1),fillOpacity=None,strokeColor=Color(0,0,.526316,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(67.57812,61.45833,23.4375,1.041667,rx=0,ry=0,fillColor=Color(0,0,.578947,1),fillOpacity=None,strokeColor=Color(0,0,.578947,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(67.57812,62.5,23.4375,1.041667,rx=0,ry=0,fillColor=Color(0,0,.631579,1),fillOpacity=None,strokeColor=Color(0,0,.631579,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(67.57812,63.54167,23.4375,1.041667,rx=0,ry=0,fillColor=Color(0,0,.684211,1),fillOpacity=None,strokeColor=Color(0,0,.684211,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(67.57812,64.58333,23.4375,1.041667,rx=0,ry=0,fillColor=Color(0,0,.736842,1),fillOpacity=None,strokeColor=Color(0,0,.736842,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(67.57812,65.625,23.4375,1.041667,rx=0,ry=0,fillColor=Color(0,0,.789474,1),fillOpacity=None,strokeColor=Color(0,0,.789474,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(67.57812,66.66667,23.4375,1.041667,rx=0,ry=0,fillColor=Color(0,0,.842105,1),fillOpacity=None,strokeColor=Color(0,0,.842105,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(67.57812,67.70833,23.4375,1.041667,rx=0,ry=0,fillColor=Color(0,0,.894737,1),fillOpacity=None,strokeColor=Color(0,0,.894737,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(67.57812,68.75,23.4375,1.041667,rx=0,ry=0,fillColor=Color(0,0,.947368,1),fillOpacity=None,strokeColor=Color(0,0,.947368,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(67.57812,69.79167,23.4375,1.041667,rx=0,ry=0,fillColor=Color(0,0,1,1),fillOpacity=None,strokeColor=Color(0,0,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(67.57812,50,23.4375,20.83333,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(217.5781,50,23.4375,6.25,rx=0,ry=0,fillColor=Color(0,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(217.5781,56.25,23.4375,6.25,rx=0,ry=0,fillColor=Color(0,0,.052632,1),fillOpacity=None,strokeColor=Color(0,0,.052632,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(217.5781,62.5,23.4375,6.25,rx=0,ry=0,fillColor=Color(0,0,.105263,1),fillOpacity=None,strokeColor=Color(0,0,.105263,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(217.5781,68.75,23.4375,6.25,rx=0,ry=0,fillColor=Color(0,0,.157895,1),fillOpacity=None,strokeColor=Color(0,0,.157895,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(217.5781,75,23.4375,6.25,rx=0,ry=0,fillColor=Color(0,0,.210526,1),fillOpacity=None,strokeColor=Color(0,0,.210526,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(217.5781,81.25,23.4375,6.25,rx=0,ry=0,fillColor=Color(0,0,.263158,1),fillOpacity=None,strokeColor=Color(0,0,.263158,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(217.5781,87.5,23.4375,6.25,rx=0,ry=0,fillColor=Color(0,0,.315789,1),fillOpacity=None,strokeColor=Color(0,0,.315789,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(217.5781,93.75,23.4375,6.25,rx=0,ry=0,fillColor=Color(0,0,.368421,1),fillOpacity=None,strokeColor=Color(0,0,.368421,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(217.5781,100,23.4375,6.25,rx=0,ry=0,fillColor=Color(0,0,.421053,1),fillOpacity=None,strokeColor=Color(0,0,.421053,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(217.5781,106.25,23.4375,6.25,rx=0,ry=0,fillColor=Color(0,0,.473684,1),fillOpacity=None,strokeColor=Color(0,0,.473684,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(217.5781,112.5,23.4375,6.25,rx=0,ry=0,fillColor=Color(0,0,.526316,1),fillOpacity=None,strokeColor=Color(0,0,.526316,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(217.5781,118.75,23.4375,6.25,rx=0,ry=0,fillColor=Color(0,0,.578947,1),fillOpacity=None,strokeColor=Color(0,0,.578947,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(217.5781,125,23.4375,6.25,rx=0,ry=0,fillColor=Color(0,0,.631579,1),fillOpacity=None,strokeColor=Color(0,0,.631579,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(217.5781,131.25,23.4375,6.25,rx=0,ry=0,fillColor=Color(0,0,.684211,1),fillOpacity=None,strokeColor=Color(0,0,.684211,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(217.5781,137.5,23.4375,6.25,rx=0,ry=0,fillColor=Color(0,0,.736842,1),fillOpacity=None,strokeColor=Color(0,0,.736842,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(217.5781,143.75,23.4375,6.25,rx=0,ry=0,fillColor=Color(0,0,.789474,1),fillOpacity=None,strokeColor=Color(0,0,.789474,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(217.5781,150,23.4375,6.25,rx=0,ry=0,fillColor=Color(0,0,.842105,1),fillOpacity=None,strokeColor=Color(0,0,.842105,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(217.5781,156.25,23.4375,6.25,rx=0,ry=0,fillColor=Color(0,0,.894737,1),fillOpacity=None,strokeColor=Color(0,0,.894737,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(217.5781,162.5,23.4375,6.25,rx=0,ry=0,fillColor=Color(0,0,.947368,1),fillOpacity=None,strokeColor=Color(0,0,.947368,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(217.5781,168.75,23.4375,6.25,rx=0,ry=0,fillColor=Color(0,0,1,1),fillOpacity=None,strokeColor=Color(0,0,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(217.5781,50,23.4375,125,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(98.04688,50,23.4375,2.083333,rx=0,ry=0,fillColor=Color(0,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(98.04688,52.08333,23.4375,2.083333,rx=0,ry=0,fillColor=Color(0,0,.052632,1),fillOpacity=None,strokeColor=Color(0,0,.052632,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(98.04688,54.16667,23.4375,2.083333,rx=0,ry=0,fillColor=Color(0,0,.105263,1),fillOpacity=None,strokeColor=Color(0,0,.105263,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(98.04688,56.25,23.4375,2.083333,rx=0,ry=0,fillColor=Color(0,0,.157895,1),fillOpacity=None,strokeColor=Color(0,0,.157895,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(98.04688,58.33333,23.4375,2.083333,rx=0,ry=0,fillColor=Color(0,0,.210526,1),fillOpacity=None,strokeColor=Color(0,0,.210526,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(98.04688,60.41667,23.4375,2.083333,rx=0,ry=0,fillColor=Color(0,0,.263158,1),fillOpacity=None,strokeColor=Color(0,0,.263158,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(98.04688,62.5,23.4375,2.083333,rx=0,ry=0,fillColor=Color(0,0,.315789,1),fillOpacity=None,strokeColor=Color(0,0,.315789,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(98.04688,64.58333,23.4375,2.083333,rx=0,ry=0,fillColor=Color(0,0,.368421,1),fillOpacity=None,strokeColor=Color(0,0,.368421,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(98.04688,66.66667,23.4375,2.083333,rx=0,ry=0,fillColor=Color(0,0,.421053,1),fillOpacity=None,strokeColor=Color(0,0,.421053,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(98.04688,68.75,23.4375,2.083333,rx=0,ry=0,fillColor=Color(0,0,.473684,1),fillOpacity=None,strokeColor=Color(0,0,.473684,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(98.04688,70.83333,23.4375,2.083333,rx=0,ry=0,fillColor=Color(0,0,.526316,1),fillOpacity=None,strokeColor=Color(0,0,.526316,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(98.04688,72.91667,23.4375,2.083333,rx=0,ry=0,fillColor=Color(0,0,.578947,1),fillOpacity=None,strokeColor=Color(0,0,.578947,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(98.04688,75,23.4375,2.083333,rx=0,ry=0,fillColor=Color(0,0,.631579,1),fillOpacity=None,strokeColor=Color(0,0,.631579,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(98.04688,77.08333,23.4375,2.083333,rx=0,ry=0,fillColor=Color(0,0,.684211,1),fillOpacity=None,strokeColor=Color(0,0,.684211,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(98.04688,79.16667,23.4375,2.083333,rx=0,ry=0,fillColor=Color(0,0,.736842,1),fillOpacity=None,strokeColor=Color(0,0,.736842,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(98.04688,81.25,23.4375,2.083333,rx=0,ry=0,fillColor=Color(0,0,.789474,1),fillOpacity=None,strokeColor=Color(0,0,.789474,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(98.04688,83.33333,23.4375,2.083333,rx=0,ry=0,fillColor=Color(0,0,.842105,1),fillOpacity=None,strokeColor=Color(0,0,.842105,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(98.04688,85.41667,23.4375,2.083333,rx=0,ry=0,fillColor=Color(0,0,.894737,1),fillOpacity=None,strokeColor=Color(0,0,.894737,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(98.04688,87.5,23.4375,2.083333,rx=0,ry=0,fillColor=Color(0,0,.947368,1),fillOpacity=None,strokeColor=Color(0,0,.947368,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(98.04688,89.58333,23.4375,2.083333,rx=0,ry=0,fillColor=Color(0,0,1,1),fillOpacity=None,strokeColor=Color(0,0,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(98.04688,50,23.4375,41.66667,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(248.0469,50,23.4375,5.208333,rx=0,ry=0,fillColor=Color(0,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(248.0469,55.20833,23.4375,5.208333,rx=0,ry=0,fillColor=Color(0,0,.052632,1),fillOpacity=None,strokeColor=Color(0,0,.052632,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(248.0469,60.41667,23.4375,5.208333,rx=0,ry=0,fillColor=Color(0,0,.105263,1),fillOpacity=None,strokeColor=Color(0,0,.105263,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(248.0469,65.625,23.4375,5.208333,rx=0,ry=0,fillColor=Color(0,0,.157895,1),fillOpacity=None,strokeColor=Color(0,0,.157895,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(248.0469,70.83333,23.4375,5.208333,rx=0,ry=0,fillColor=Color(0,0,.210526,1),fillOpacity=None,strokeColor=Color(0,0,.210526,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(248.0469,76.04167,23.4375,5.208333,rx=0,ry=0,fillColor=Color(0,0,.263158,1),fillOpacity=None,strokeColor=Color(0,0,.263158,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(248.0469,81.25,23.4375,5.208333,rx=0,ry=0,fillColor=Color(0,0,.315789,1),fillOpacity=None,strokeColor=Color(0,0,.315789,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(248.0469,86.45833,23.4375,5.208333,rx=0,ry=0,fillColor=Color(0,0,.368421,1),fillOpacity=None,strokeColor=Color(0,0,.368421,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(248.0469,91.66667,23.4375,5.208333,rx=0,ry=0,fillColor=Color(0,0,.421053,1),fillOpacity=None,strokeColor=Color(0,0,.421053,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(248.0469,96.875,23.4375,5.208333,rx=0,ry=0,fillColor=Color(0,0,.473684,1),fillOpacity=None,strokeColor=Color(0,0,.473684,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(248.0469,102.0833,23.4375,5.208333,rx=0,ry=0,fillColor=Color(0,0,.526316,1),fillOpacity=None,strokeColor=Color(0,0,.526316,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(248.0469,107.2917,23.4375,5.208333,rx=0,ry=0,fillColor=Color(0,0,.578947,1),fillOpacity=None,strokeColor=Color(0,0,.578947,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(248.0469,112.5,23.4375,5.208333,rx=0,ry=0,fillColor=Color(0,0,.631579,1),fillOpacity=None,strokeColor=Color(0,0,.631579,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(248.0469,117.7083,23.4375,5.208333,rx=0,ry=0,fillColor=Color(0,0,.684211,1),fillOpacity=None,strokeColor=Color(0,0,.684211,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(248.0469,122.9167,23.4375,5.208333,rx=0,ry=0,fillColor=Color(0,0,.736842,1),fillOpacity=None,strokeColor=Color(0,0,.736842,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(248.0469,128.125,23.4375,5.208333,rx=0,ry=0,fillColor=Color(0,0,.789474,1),fillOpacity=None,strokeColor=Color(0,0,.789474,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(248.0469,133.3333,23.4375,5.208333,rx=0,ry=0,fillColor=Color(0,0,.842105,1),fillOpacity=None,strokeColor=Color(0,0,.842105,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(248.0469,138.5417,23.4375,5.208333,rx=0,ry=0,fillColor=Color(0,0,.894737,1),fillOpacity=None,strokeColor=Color(0,0,.894737,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(248.0469,143.75,23.4375,5.208333,rx=0,ry=0,fillColor=Color(0,0,.947368,1),fillOpacity=None,strokeColor=Color(0,0,.947368,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(248.0469,148.9583,23.4375,5.208333,rx=0,ry=0,fillColor=Color(0,0,1,1),fillOpacity=None,strokeColor=Color(0,0,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(248.0469,50,23.4375,104.1667,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(128.5156,50,23.4375,3.125,rx=0,ry=0,fillColor=Color(0,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(128.5156,53.125,23.4375,3.125,rx=0,ry=0,fillColor=Color(.052632,.039628,.041899,1),fillOpacity=None,strokeColor=Color(.052632,.039628,.041899,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(128.5156,56.25,23.4375,3.125,rx=0,ry=0,fillColor=Color(.105263,.079257,.083798,1),fillOpacity=None,strokeColor=Color(.105263,.079257,.083798,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(128.5156,59.375,23.4375,3.125,rx=0,ry=0,fillColor=Color(.157895,.118885,.125697,1),fillOpacity=None,strokeColor=Color(.157895,.118885,.125697,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(128.5156,62.5,23.4375,3.125,rx=0,ry=0,fillColor=Color(.210526,.158514,.167595,1),fillOpacity=None,strokeColor=Color(.210526,.158514,.167595,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(128.5156,65.625,23.4375,3.125,rx=0,ry=0,fillColor=Color(.263158,.198142,.209494,1),fillOpacity=None,strokeColor=Color(.263158,.198142,.209494,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(128.5156,68.75,23.4375,3.125,rx=0,ry=0,fillColor=Color(.315789,.237771,.251393,1),fillOpacity=None,strokeColor=Color(.315789,.237771,.251393,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(128.5156,71.875,23.4375,3.125,rx=0,ry=0,fillColor=Color(.368421,.277399,.293292,1),fillOpacity=None,strokeColor=Color(.368421,.277399,.293292,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(128.5156,75,23.4375,3.125,rx=0,ry=0,fillColor=Color(.421053,.317028,.335191,1),fillOpacity=None,strokeColor=Color(.421053,.317028,.335191,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(128.5156,78.125,23.4375,3.125,rx=0,ry=0,fillColor=Color(.473684,.356656,.37709,1),fillOpacity=None,strokeColor=Color(.473684,.356656,.37709,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(128.5156,81.25,23.4375,3.125,rx=0,ry=0,fillColor=Color(.526316,.396285,.418989,1),fillOpacity=None,strokeColor=Color(.526316,.396285,.418989,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(128.5156,84.375,23.4375,3.125,rx=0,ry=0,fillColor=Color(.578947,.435913,.460888,1),fillOpacity=None,strokeColor=Color(.578947,.435913,.460888,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(128.5156,87.5,23.4375,3.125,rx=0,ry=0,fillColor=Color(.631579,.475542,.502786,1),fillOpacity=None,strokeColor=Color(.631579,.475542,.502786,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(128.5156,90.625,23.4375,3.125,rx=0,ry=0,fillColor=Color(.684211,.51517,.544685,1),fillOpacity=None,strokeColor=Color(.684211,.51517,.544685,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(128.5156,93.75,23.4375,3.125,rx=0,ry=0,fillColor=Color(.736842,.554799,.586584,1),fillOpacity=None,strokeColor=Color(.736842,.554799,.586584,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(128.5156,96.875,23.4375,3.125,rx=0,ry=0,fillColor=Color(.789474,.594427,.628483,1),fillOpacity=None,strokeColor=Color(.789474,.594427,.628483,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(128.5156,100,23.4375,3.125,rx=0,ry=0,fillColor=Color(.842105,.634056,.670382,1),fillOpacity=None,strokeColor=Color(.842105,.634056,.670382,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(128.5156,103.125,23.4375,3.125,rx=0,ry=0,fillColor=Color(.894737,.673684,.712281,1),fillOpacity=None,strokeColor=Color(.894737,.673684,.712281,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(128.5156,106.25,23.4375,3.125,rx=0,ry=0,fillColor=Color(.947368,.713313,.75418,1),fillOpacity=None,strokeColor=Color(.947368,.713313,.75418,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(128.5156,109.375,23.4375,3.125,rx=0,ry=0,fillColor=Color(1,.752941,.796078,1),fillOpacity=None,strokeColor=Color(1,.752941,.796078,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(128.5156,50,23.4375,62.5,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(278.5156,50,23.4375,4.166667,rx=0,ry=0,fillColor=Color(0,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(278.5156,54.16667,23.4375,4.166667,rx=0,ry=0,fillColor=Color(.052632,.039628,.041899,1),fillOpacity=None,strokeColor=Color(.052632,.039628,.041899,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(278.5156,58.33333,23.4375,4.166667,rx=0,ry=0,fillColor=Color(.105263,.079257,.083798,1),fillOpacity=None,strokeColor=Color(.105263,.079257,.083798,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(278.5156,62.5,23.4375,4.166667,rx=0,ry=0,fillColor=Color(.157895,.118885,.125697,1),fillOpacity=None,strokeColor=Color(.157895,.118885,.125697,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(278.5156,66.66667,23.4375,4.166667,rx=0,ry=0,fillColor=Color(.210526,.158514,.167595,1),fillOpacity=None,strokeColor=Color(.210526,.158514,.167595,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(278.5156,70.83333,23.4375,4.166667,rx=0,ry=0,fillColor=Color(.263158,.198142,.209494,1),fillOpacity=None,strokeColor=Color(.263158,.198142,.209494,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(278.5156,75,23.4375,4.166667,rx=0,ry=0,fillColor=Color(.315789,.237771,.251393,1),fillOpacity=None,strokeColor=Color(.315789,.237771,.251393,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(278.5156,79.16667,23.4375,4.166667,rx=0,ry=0,fillColor=Color(.368421,.277399,.293292,1),fillOpacity=None,strokeColor=Color(.368421,.277399,.293292,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(278.5156,83.33333,23.4375,4.166667,rx=0,ry=0,fillColor=Color(.421053,.317028,.335191,1),fillOpacity=None,strokeColor=Color(.421053,.317028,.335191,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(278.5156,87.5,23.4375,4.166667,rx=0,ry=0,fillColor=Color(.473684,.356656,.37709,1),fillOpacity=None,strokeColor=Color(.473684,.356656,.37709,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(278.5156,91.66667,23.4375,4.166667,rx=0,ry=0,fillColor=Color(.526316,.396285,.418989,1),fillOpacity=None,strokeColor=Color(.526316,.396285,.418989,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(278.5156,95.83333,23.4375,4.166667,rx=0,ry=0,fillColor=Color(.578947,.435913,.460888,1),fillOpacity=None,strokeColor=Color(.578947,.435913,.460888,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(278.5156,100,23.4375,4.166667,rx=0,ry=0,fillColor=Color(.631579,.475542,.502786,1),fillOpacity=None,strokeColor=Color(.631579,.475542,.502786,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(278.5156,104.1667,23.4375,4.166667,rx=0,ry=0,fillColor=Color(.684211,.51517,.544685,1),fillOpacity=None,strokeColor=Color(.684211,.51517,.544685,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(278.5156,108.3333,23.4375,4.166667,rx=0,ry=0,fillColor=Color(.736842,.554799,.586584,1),fillOpacity=None,strokeColor=Color(.736842,.554799,.586584,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(278.5156,112.5,23.4375,4.166667,rx=0,ry=0,fillColor=Color(.789474,.594427,.628483,1),fillOpacity=None,strokeColor=Color(.789474,.594427,.628483,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(278.5156,116.6667,23.4375,4.166667,rx=0,ry=0,fillColor=Color(.842105,.634056,.670382,1),fillOpacity=None,strokeColor=Color(.842105,.634056,.670382,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(278.5156,120.8333,23.4375,4.166667,rx=0,ry=0,fillColor=Color(.894737,.673684,.712281,1),fillOpacity=None,strokeColor=Color(.894737,.673684,.712281,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(278.5156,125,23.4375,4.166667,rx=0,ry=0,fillColor=Color(.947368,.713313,.75418,1),fillOpacity=None,strokeColor=Color(.947368,.713313,.75418,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(278.5156,129.1667,23.4375,4.166667,rx=0,ry=0,fillColor=Color(1,.752941,.796078,1),fillOpacity=None,strokeColor=Color(1,.752941,.796078,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(278.5156,50,23.4375,83.33333,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(158.9844,50,1.116071,83.33333,rx=0,ry=0,fillColor=Color(0,0,1,1),fillOpacity=None,strokeColor=Color(0,0,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(160.1004,50,1.116071,83.33333,rx=0,ry=0,fillColor=Color(.090909,.090909,1,1),fillOpacity=None,strokeColor=Color(.090909,.090909,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(161.2165,50,1.116071,83.33333,rx=0,ry=0,fillColor=Color(.181818,.181818,1,1),fillOpacity=None,strokeColor=Color(.181818,.181818,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(162.3326,50,1.116071,83.33333,rx=0,ry=0,fillColor=Color(.272727,.272727,1,1),fillOpacity=None,strokeColor=Color(.272727,.272727,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(163.4487,50,1.116071,83.33333,rx=0,ry=0,fillColor=Color(.363636,.363636,1,1),fillOpacity=None,strokeColor=Color(.363636,.363636,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(164.5647,50,1.116071,83.33333,rx=0,ry=0,fillColor=Color(.454545,.454545,1,1),fillOpacity=None,strokeColor=Color(.454545,.454545,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(165.6808,50,1.116071,83.33333,rx=0,ry=0,fillColor=Color(.545455,.545455,1,1),fillOpacity=None,strokeColor=Color(.545455,.545455,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(166.7969,50,1.116071,83.33333,rx=0,ry=0,fillColor=Color(.636364,.636364,1,1),fillOpacity=None,strokeColor=Color(.636364,.636364,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(167.9129,50,1.116071,83.33333,rx=0,ry=0,fillColor=Color(.727273,.727273,1,1),fillOpacity=None,strokeColor=Color(.727273,.727273,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(169.029,50,1.116071,83.33333,rx=0,ry=0,fillColor=Color(.818182,.818182,1,1),fillOpacity=None,strokeColor=Color(.818182,.818182,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(170.1451,50,1.116071,83.33333,rx=0,ry=0,fillColor=Color(.909091,.909091,1,1),fillOpacity=None,strokeColor=Color(.909091,.909091,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(171.2612,50,1.116071,83.33333,rx=0,ry=0,fillColor=Color(1,1,1,1),fillOpacity=None,strokeColor=Color(1,1,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(172.3772,50,1.116071,83.33333,rx=0,ry=0,fillColor=Color(.888889,.888889,1,1),fillOpacity=None,strokeColor=Color(.888889,.888889,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(173.4933,50,1.116071,83.33333,rx=0,ry=0,fillColor=Color(.777778,.777778,1,1),fillOpacity=None,strokeColor=Color(.777778,.777778,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(174.6094,50,1.116071,83.33333,rx=0,ry=0,fillColor=Color(.666667,.666667,1,1),fillOpacity=None,strokeColor=Color(.666667,.666667,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(175.7254,50,1.116071,83.33333,rx=0,ry=0,fillColor=Color(.555556,.555556,1,1),fillOpacity=None,strokeColor=Color(.555556,.555556,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(176.8415,50,1.116071,83.33333,rx=0,ry=0,fillColor=Color(.444444,.444444,1,1),fillOpacity=None,strokeColor=Color(.444444,.444444,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(177.9576,50,1.116071,83.33333,rx=0,ry=0,fillColor=Color(.333333,.333333,1,1),fillOpacity=None,strokeColor=Color(.333333,.333333,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(179.0737,50,1.116071,83.33333,rx=0,ry=0,fillColor=Color(.222222,.222222,1,1),fillOpacity=None,strokeColor=Color(.222222,.222222,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(180.1897,50,1.116071,83.33333,rx=0,ry=0,fillColor=Color(.111111,.111111,1,1),fillOpacity=None,strokeColor=Color(.111111,.111111,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(181.3058,50,1.116071,83.33333,rx=0,ry=0,fillColor=Color(0,0,1,1),fillOpacity=None,strokeColor=Color(0,0,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(158.9844,50,23.4375,83.33333,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(308.9844,50,1.116071,62.5,rx=0,ry=0,fillColor=Color(0,0,1,1),fillOpacity=None,strokeColor=Color(0,0,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(310.1004,50,1.116071,62.5,rx=0,ry=0,fillColor=Color(.090909,.090909,1,1),fillOpacity=None,strokeColor=Color(.090909,.090909,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(311.2165,50,1.116071,62.5,rx=0,ry=0,fillColor=Color(.181818,.181818,1,1),fillOpacity=None,strokeColor=Color(.181818,.181818,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(312.3326,50,1.116071,62.5,rx=0,ry=0,fillColor=Color(.272727,.272727,1,1),fillOpacity=None,strokeColor=Color(.272727,.272727,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(313.4487,50,1.116071,62.5,rx=0,ry=0,fillColor=Color(.363636,.363636,1,1),fillOpacity=None,strokeColor=Color(.363636,.363636,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(314.5647,50,1.116071,62.5,rx=0,ry=0,fillColor=Color(.454545,.454545,1,1),fillOpacity=None,strokeColor=Color(.454545,.454545,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(315.6808,50,1.116071,62.5,rx=0,ry=0,fillColor=Color(.545455,.545455,1,1),fillOpacity=None,strokeColor=Color(.545455,.545455,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(316.7969,50,1.116071,62.5,rx=0,ry=0,fillColor=Color(.636364,.636364,1,1),fillOpacity=None,strokeColor=Color(.636364,.636364,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(317.9129,50,1.116071,62.5,rx=0,ry=0,fillColor=Color(.727273,.727273,1,1),fillOpacity=None,strokeColor=Color(.727273,.727273,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(319.029,50,1.116071,62.5,rx=0,ry=0,fillColor=Color(.818182,.818182,1,1),fillOpacity=None,strokeColor=Color(.818182,.818182,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(320.1451,50,1.116071,62.5,rx=0,ry=0,fillColor=Color(.909091,.909091,1,1),fillOpacity=None,strokeColor=Color(.909091,.909091,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(321.2612,50,1.116071,62.5,rx=0,ry=0,fillColor=Color(1,1,1,1),fillOpacity=None,strokeColor=Color(1,1,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(322.3772,50,1.116071,62.5,rx=0,ry=0,fillColor=Color(.888889,.888889,1,1),fillOpacity=None,strokeColor=Color(.888889,.888889,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(323.4933,50,1.116071,62.5,rx=0,ry=0,fillColor=Color(.777778,.777778,1,1),fillOpacity=None,strokeColor=Color(.777778,.777778,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(324.6094,50,1.116071,62.5,rx=0,ry=0,fillColor=Color(.666667,.666667,1,1),fillOpacity=None,strokeColor=Color(.666667,.666667,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(325.7254,50,1.116071,62.5,rx=0,ry=0,fillColor=Color(.555556,.555556,1,1),fillOpacity=None,strokeColor=Color(.555556,.555556,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(326.8415,50,1.116071,62.5,rx=0,ry=0,fillColor=Color(.444444,.444444,1,1),fillOpacity=None,strokeColor=Color(.444444,.444444,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(327.9576,50,1.116071,62.5,rx=0,ry=0,fillColor=Color(.333333,.333333,1,1),fillOpacity=None,strokeColor=Color(.333333,.333333,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(329.0737,50,1.116071,62.5,rx=0,ry=0,fillColor=Color(.222222,.222222,1,1),fillOpacity=None,strokeColor=Color(.222222,.222222,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(330.1897,50,1.116071,62.5,rx=0,ry=0,fillColor=Color(.111111,.111111,1,1),fillOpacity=None,strokeColor=Color(.111111,.111111,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(331.3058,50,1.116071,62.5,rx=0,ry=0,fillColor=Color(0,0,1,1),fillOpacity=None,strokeColor=Color(0,0,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(308.9844,50,23.4375,62.5,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,50,350,50,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,50,50,45,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(200,50,200,45,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(350,50,350,45,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,125,45)
		v0.add(String(-20,-4,'Ying',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,275,45)
		v0.add(String(-21.66,-4,'Yang',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		self.add(Line(50,50,50,175,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,50,45,50,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,81.25,45,81.25,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,112.5,45,112.5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,143.75,45,143.75,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,175,45,175,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,50)
		v0.add(String(-5,-4,'0',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,81.25)
		v0.add(String(-10,-4,'15',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,112.5)
		v0.add(String(-10,-4,'30',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,143.75)
		v0.add(String(-10,-4,'45',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,175)
		v0.add(String(-10,-4,'60',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))


if __name__=="__main__": #NORUNTESTS
	ExplodedDrawing_Drawing().save(formats=['pdf'],outDir='.',fnRoot=None)



#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.shapes import _DrawingEditorMixin, Drawing, Group, Line, Wedge, String
from reportlab.lib.colors import Color, CMYKColor, PCMYKColor

class ExplodedDrawing_Drawing(_DrawingEditorMixin,Drawing):
	def __init__(self,width=400,height=200,*args,**kw):
		Drawing.__init__(self,width,height,*args,**kw)
		self.transform = (1,0,0,1,0,0)
		self.add(Line(0,0,0,200,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Wedge(75,100,75,-351.4,-85,yradius=75,annular=False,fillColor=Color(.27451,.509804,.705882,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Wedge(75,100,75,-355,-351.4,yradius=75,annular=False,fillColor=Color(.847059,.74902,.847059,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Wedge(75,100,75,-358.6,-355,yradius=75,annular=False,fillColor=Color(.392157,.584314,.929412,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Wedge(75,100,75,-362.2,-358.6,yradius=75,annular=False,fillColor=Color(.690196,.768627,.870588,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Wedge(75,100,75,-365.8,-362.2,yradius=75,annular=False,fillColor=Color(.498039,1,.831373,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Wedge(75,100,75,-445,-365.8,yradius=75,annular=False,fillColor=Color(.372549,.619608,.627451,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(String(-15,155.6568,'example1',textAnchor='end',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		self.add(String(165,110.6564,'example2',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		self.add(String(165,105.0239,'example3',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		self.add(String(165,99.37169,'example4',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		self.add(String(165,93.72192,'example5',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		self.add(String(165,35.91766,'example6',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		self.add(Line(16.06073,146.3806,.530367,158.6568,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(.530367,158.6568,-15,158.6568,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(149.4724,108.8803,157.2362,113.6564,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(157.2362,113.6564,165,113.6564,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(149.8831,104.1866,157.4415,108.0239,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(157.4415,108.0239,165,108.0239,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(149.9982,99.47641,157.4991,102.3717,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(157.4991,102.3717,165,102.3717,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(149.8173,94.76826,157.4087,96.72192,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(157.4087,96.72192,165,96.72192,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(127.6615,46.59805,146.3307,38.91766,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(146.3307,38.91766,165,38.91766,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))


if __name__=="__main__": #NORUNTESTS
	ExplodedDrawing_Drawing().save(formats=['pdf'],outDir='.',fnRoot=None)



#Copyright ReportLab Europe Ltd. 2000-2017
#see license.txt for license details
"""Tests for context-dependent indentation
"""
__version__='3.3.0'
from reportlab.lib.testutils import setOutDir,makeSuiteForClasses, outputfile, printLocation
setOutDir(__name__)
import sys, os
from operator import truth
import unittest
from reportlab.pdfbase.pdfmetrics import stringWidth
from reportlab.platypus.paraparser import ParaParser
from reportlab.platypus.flowables import Flowable
from reportlab.lib.colors import Color
from reportlab.lib.units import cm
from reportlab.lib.enums import TA_LEFT, TA_RIGHT, TA_CENTER, TA_JUSTIFY
from reportlab.lib.utils import _className
from reportlab.lib.styles import getSampleStyleSheet, ParagraphStyle
from reportlab.platypus.paragraph import Paragraph
from reportlab.platypus.frames import Frame
from reportlab.platypus.doctemplate \
     import PageTemplate, BaseDocTemplate, Indenter, FrameBreak, NextPageTemplate
from reportlab.platypus import tableofcontents
from reportlab.platypus.tableofcontents import TableOfContents
from reportlab.platypus.tables import TableStyle, Table
from reportlab.platypus.paragraph import *
from reportlab.platypus.paragraph import _getFragWords
from reportlab.platypus.flowables import Spacer


def myMainPageFrame(canvas, doc):
    "The page frame used for all PDF documents."

    canvas.saveState()

    canvas.rect(2.5*cm, 2.5*cm, 15*cm, 25*cm)
    canvas.setFont('Times-Roman', 12)
    pageNumber = canvas.getPageNumber()
    canvas.drawString(10*cm, cm, str(pageNumber))

    canvas.restoreState()


class MyDocTemplate(BaseDocTemplate):
    _invalidInitArgs = ('pageTemplates',)

    def __init__(self, filename, **kw):
        frame1 = Frame(2.5*cm, 2.5*cm, 15*cm, 25*cm, id='F1')
        self.allowSplitting = 0
        BaseDocTemplate.__init__(self, filename, **kw)
        template1 = PageTemplate('normal', [frame1], myMainPageFrame)

        frame2 = Frame(2.5*cm, 16*cm, 15*cm, 10*cm, id='F2', showBoundary=1)
        frame3 = Frame(2.5*cm, 2.5*cm, 15*cm, 10*cm, id='F3', showBoundary=1)

        template2 = PageTemplate('updown', [frame2, frame3])
        self.addPageTemplates([template1, template2])


class WrappingTestCase(unittest.TestCase):
    "Test wrapping of long urls"

    def test0(self):
        "test_platypus_wrapping.WrappingTestCase.test0"

        # Build story.
        story = []

        styleSheet = getSampleStyleSheet()
        h1 = styleSheet['Heading1']
        h1.spaceBefore = 18
        bt = styleSheet['BodyText']
        bt.spaceBefore = 6

        story.append(Paragraph('Test of paragraph wrapping',h1))

        story.append(Spacer(18,18))

        txt = "Normally we wrap paragraphs by looking for spaces between the words.  However, with long technical command references and URLs, sometimes this gives ugly results.  We attempt to split really long words on certain tokens:  slashes, dots etc."

        story.append(Paragraph(txt,bt))
        
        story.append(Paragraph('This is an attempt to break long URLs sanely.  Here is a file name: <font face="Courier">C:\\Windows\\System32\\Drivers\\etc\\hosts</font>.  ', bt))
        

        story.append(Paragraph('This paragraph has a URL (basically, a word) too long to fit on one line, so it just overflows. http://some-really-long-site.somewhere-verbose.com/webthingies/framework/xc4987236hgsdlkafh/foo?format=dingbats&amp;content=rubbish. Ideally, we would wrap it in the middle.', bt))


        
        
        doc = MyDocTemplate(outputfile('test_platypus_wrapping.pdf'))
        doc.multiBuild(story)

#noruntests
def makeSuite():
    return makeSuiteForClasses(WrappingTestCase)


#noruntests
if __name__ == "__main__":
    unittest.TextTestRunner().run(makeSuite())
    printLocation()
